<?php
    class UIPSIMLibInternational {
        public $utoken; // User token
        public $error;	// This error message output
        public $timeout = 5; // This timeout
        public $rid; 		// This Report ID
        private $url    = "https://www.uipsim.com/app/api/international-sms/"; // This Data URL

        public function __construct($utoken='') {
            $this->utoken   = $utoken;
        }

        private function curl_use ($site_url,$post_data){
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL,$site_url);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS,$post_data);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);
            curl_setopt($ch, CURLOPT_HEADER, 0);
            //curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
            curl_setopt($ch, CURLOPT_TIMEOUT, $this->timeout);
            $result = curl_exec($ch);
            return $result;
        }

        public function Submit($title = NULL,$message = NULL,$number = 0){
            $numbers	= is_array($number) ? $number : [$number];

            $json_data  = Utility::jencode([
                'user_token' => $this->utoken,
                'origin' => $title,
                'message' => $message,
                'numbers' => $numbers,
            ]);

            $outcome = $this->curl_use($this->url.'submit',$json_data);
            $solve = Utility::jdecode($outcome,true);

            Modules::save_log("SMS","UIPSIM","sms",$solve,$numbers,$json_data);

            if($solve){
                if(isset($solve["status"]) && $solve["status"] == "successful"){
                    $this->rid = $solve["report_id"];
                    return true;
                }else{
                    $this->error = isset($solve["message"]) ? $solve["message"] : "Submission Failed";
                    return false;
                }
            }else{
                $this->error = "The API response could not be resolved.";
                return false;
            }
        }

        public function Balance(){

            $json_data    = Utility::jencode([
                'user_token' => $this->utoken,
            ]);

            $outcome = $this->curl_use($this->url.'balance',$json_data);
            $solve = Utility::jdecode($outcome,true);
            if($solve){
                if(isset($solve["status"]) && $solve["status"] == "successful"){
                    return [
                        'balance'  => $solve["unformatted"],
                        'currency' => $solve["currency"],
                    ];
                }else{
                    $this->error = $solve["message"];
                    return false;
                }
            }else{
                $this->error = "The API response could not be resolved.";
                return false;
            }
        }

        public function ReportLook($rid){

            $json_data = Utility::jencode([
                'user_token' => $this->utoken,
                'report_id' => $rid,
            ]);

            $outcome = $this->curl_use($this->url.'report',$json_data);
            $solve = Utility::jdecode($outcome,true);
            if($solve){
                if(isset($solve["status"]) && $solve["status"] == "successful"){
                    return [
                        'enroute'  => $solve["waiting"],
                        'delivered' => $solve["conducted"],
                        'undelivered' => $solve["erroneous"],
                    ];
                }else{
                    $this->error = $solve["message"];
                    return false;
                }
            }else{
                $this->error = "The API response could not be resolved.";
                return false;
            }
        }

        public function get_prices(){
            $json_data = Utility::jencode([
                'user_token' => $this->utoken,
            ]);

            $outcome = $this->curl_use($this->url.'prices',$json_data);
            $solve = Utility::jdecode($outcome,true);
            if($solve){
                if(isset($solve["status"]) && $solve["status"] == "successful"){
                    return $solve["prices"];
                }else{
                    $this->error = $solve["message"];
                    return false;
                }
            }else{
                $this->error = "The API response could not be resolved.";
                return false;
            }
        }

    }